==> kadm-webtool-0.3.3.tgz: package/cli/webtool.js <==
#!/usr/bin/env node
//'use strict';

const gulp = require('gulp');
const less = require('gulp-less');
const Liftoff = require('liftoff');
const _ = require('lodash');
const path = require('path');
const concat = require('gulp-concat');
const rename = require('gulp-rename');
const babel = require('gulp-babel');
const uglify = require('gulp-uglify');
const browserify = require('browserify');
const vsstream = require('vinyl-source-stream');
const moment = require('moment');
const chalk = require('chalk');
const argv = require('minimist')(process.argv.slice(2));
const fs = require('fs');
const Stream = require('stream');

const imagemin = require('gulp-imagemin');
const imageRecompress = require('imagemin-jpeg-recompress');
const pngquant = require('imagemin-pngquant');
const cache = require('gulp-cache');

var jsonPath = path.join(process.argv[1], "../../toolconf.json");
var config =JSON.parse(fs.readFileSync(jsonPath.toLocaleString()));

const timeFormat = "YYYY-MM-DD hh:mm:ss";

var webtool = new Liftoff({
    name: 'webtool', // 命令名字
    processTitle: 'webtool', //同上即可
    moduleName: 'webtool', //同上即可
    configFiles: {
        'toolconf.json': {
            cwd: '.'
        }
    },

    extensions: {
        '.js': null
    }
});

const commands = [
    {command:"init", label:"初始化,创建一个配置文件"},
    {command:"listen", label:"开始监听配置的变化"}
]

function ctimestr(){
    return chalk.yellow(moment().format(timeFormat));
}

//启动命令
webtool.launch({
        cwd: argv.r || argv.root, //当前输入命令的目录
        configPath: argv.f || argv.file //读取当前命令目录下的配置文件路径
    }, function(env, enc) {

        //捕获命令行
    var command = argv["_"];
    if (argv.h){
        help();
    }
    if (command.length > 0)
    {
        switch (command[0]){
            case "init":
                init(env);
                break;

            case "listen":
                listen(env);
                break;

            default:
        }
    }


});

function init(env){
    gulp.src(jsonPath.toLocaleString())
        .pipe(gulp.dest('./'))
        .on("finish", function (){
            console.log('create config json file!');
        })

}
function listen(env){
    var config = require(path.join(env.cwd, 'toolconf.json'));
    var queue = config.convert;
    _.forEach(queue, function(obj){
        if(obj.source){
            const watchTarget = obj.watch || obj.source;
            switch (obj.type.toLowerCase()){
                case "css":
                    converCss(env, obj.source, obj.dest);
                    gulp.watch(watchTarget, function(){
                        console.log(`files in ${watchTarget} seems to be modified, start reconvert @${ctimestr()}`)
                        converCss(env, obj.source, obj.dest);
                    });
                    break;
                case "js":
                    converJs(env, obj.source, obj.dest);
                    gulp.watch(watchTarget, function(){
                        console.log(`files in ${watchTarget} seems to be modified, start reconvert @${ctimestr()}`)
                        converJs(env, obj.source, obj.dest);

                    });
                    break;
                case "browserify":
                    converBrowserifyJs(env, obj.source, obj.dest);
                    gulp.watch(watchTarget, function(){
                        console.log(`files in ${watchTarget} seems to be modified, start reconvert @${ctimestr()}`)
                        converBrowserifyJs(env, obj.source, obj.dest);
                    });
                    break;
                case "image":
                    compressImages(env, obj.source, obj.dest, obj.quality);
                    gulp.watch(watchTarget, function(){
                        console.log(watchTarget);
                        console.log(`files in ${watchTarget} seems to be modified, start compress @${ctimestr()}`)
                        compressImages(env, watchTarget, obj.dest, obj.quality);
                    });
                    break;

            }
        }

    });
}
function converCss(evn, source, dest){
    var lessobj = less();
    const cssnano = require('gulp-cssnano');
    const extname = path.extname(dest);
    const basename = path.basename(dest);
    var stream = gulp.src(source)
        .pipe(lessobj).on('error', function(error){
            console.log(error.toLocaleString());
            console.log('不能转换目标js');
            this.emit("end");
        });

    if(extname.length > 0){
        stream = stream.pipe(concat(basename));
        destPath = path.dirname(dest);
    }
    else {
        destPath = dest
    }
    stream = stream.pipe(cssnano())
        .pipe(rename(function(path){
            path.basename += '.min';
        }))
        .pipe(gulp.dest(destPath))
        .on('finish', function(file){
            console.log('finish convert css file');
        });
    return stream;
}
function converJs(evn, source, dest){
    const cssnano = require('gulp-cssnano');
    const extname = path.extname(dest);
    const basename = path.basename(dest);
    const sourceExtName = path.extname(source);

    var stream = gulp.src(source)
        .pipe(babel({
            presets: ['es2015']

        }).on('error', function(error){
            console.log(error.toLocaleString());
            console.log('不能转换目标js');
            this.emit("end")
        }))
        .pipe(uglify());

    var destPath;
    if(extname.length > 0){
        console.log('concat');
        stream = stream.pipe(concat(basename));
        destPath = path.dirname(dest);
    }else{
        destPath = dest
    }
    console.log(destPath);
    stream = stream.pipe(gulp.dest(destPath))
        .on('finish', function(file){
            console.log('finish convert js file');
        });
    return stream;
}
function converBrowserifyJs(env, source, dest){
    const extname = path.extname(dest);
    const destfolder = path.dirname(dest);
    if (extname.length == 0) return;
    console.log('browserify');
    var b = browserify({
        entries: source
    });
    return b.bundle()
        .on('error', function(err){
            console.log('browserify fail, can not convert\n' + source + "to \n" + dest);
            console.log(err);
        })
        .pipe(vsstream(path.basename(dest)))
        .pipe(gulp.dest(destfolder)).on('finish', function(file){
            console.log('finish build bundle js file');
        });
}
function compressImages(evn, source, dest, quality){
    gulp.src(source)
        .pipe(cache(imagemin({
            optimizationLevel: 0, //类型：Number  默认：3  取值范围：0-7（优化等级）
            //progressive: true, //类型：Boolean 默认：false 无损压缩jpg图片
            //interlaced: true, //类型：Boolean 默认：false 隔行扫描gif进行渲染
            //multipass: true, //类型：Boolean 默认：false 多次优化svg直到完全优化
            use:[
                imageRecompress({
                    accurate: false,//高精度模式
                    quality: "low",//图像质量:low, medium, high and veryhigh;
                    method: "smallfry",//网格优化:mpe, ssim, ms-ssim and smallfry;
                    min: 60,//最低质量
                    strip:true,
                    target:0.1,
                    loops: 6,//循环尝试次数, 默认为6;
                    progressive: true,//基线优化
                    subsample: "default"//子采样:default, disable;
                    }
                ),
                pngquant({
                    optimizationLevel: 4
                })
            ]
        })))
        .pipe(gulp.dest(dest))
        .on('finish', function(file){
            console.log('finish compress image');
        });;

}
function help(){
    console.log("webtool [<param>] -h");
    console.log("-h ——呼叫帮助");
    _.forEach(commands, function (obj){
        console.log(`<param>:${obj.command} -- ${obj.label}`);
    });
}

==> kadm-webtool-0.3.6.tgz: package/cli/webtool.js <==
#!/usr/bin/env node
//'use strict';

const gulp = require('gulp');
const less = require('gulp-less');
const Liftoff = require('liftoff');
const _ = require('lodash');
const path = require('path');
const concat = require('gulp-concat');
const rename = require('gulp-rename');
const babel = require('gulp-babel');
const uglify = require('gulp-uglify');
const browserify = require('browserify');
const vsstream = require('vinyl-source-stream');
const moment = require('moment');
const chalk = require('chalk');
const argv = require('minimist')(process.argv.slice(2));
const fs = require('fs');
const Stream = require('stream');

const imagemin = require('gulp-imagemin');
const imageRecompress = require('imagemin-jpeg-recompress');
const pngquant = require('imagemin-pngquant');
const cache = require('gulp-cache');


var config;

const timeFormat = "YYYY-MM-DD hh:mm:ss";

var webtool = new Liftoff({
    name: 'webtool', // 命令名字
    processTitle: 'webtool', //同上即可
    moduleName: 'webtool', //同上即可
    configFiles: {
        'toolconf.json': {
            cwd: '.'
        }
    },

    extensions: {
        '.js': null
    }
});

const commands = [
    {command:"init", label:"初始化,创建一个配置文件"},
    {command:"listen", label:"开始监听配置的变化"}
]

function ctimestr(){
    return chalk.yellow(moment().format(timeFormat));
}

//启动命令
webtool.launch({
        cwd: argv.r || argv.root, //当前输入命令的目录
        configPath: argv.f || argv.file //读取当前命令目录下的配置文件路径
    }, function(env, enc) {

        //捕获命令行
    var command = argv["_"];
    if (argv.h){
        help();
    }
    if (command.length > 0)
    {
        switch (command[0]){
            case "init":
                init(env);
                break;

            case "listen":
                listen(env);
                break;

            default:
        }
    }


});

function init(env){
    var jsonPath = path.join(process.mainModule.filename, "../../toolconf.json");
    config = JSON.parse(fs.readFileSync(jsonPath.toLocaleString()));

    gulp.src(jsonPath.toLocaleString())
        .pipe(gulp.dest('./'))
        .on("finish", function (){
            console.log('create config json file!');
        })

}
function listen(env){
    var config = require(path.join(env.cwd, 'toolconf.json'));
    var queue = config.convert;
    _.forEach(queue, function(obj){
        if(obj.source){
            const watchTarget = obj.watch || obj.source;
            switch (obj.type.toLowerCase()){
                case "css":
                    converCss(env, obj.source, obj.dest);
                    gulp.watch(watchTarget, function(){
                        console.log(`files in ${watchTarget} seems to be modified, start reconvert @${ctimestr()}`)
                        converCss(env, obj.source, obj.dest);
                    });
                    break;
                case "js":
                    converJs(env, obj.source, obj.dest);
                    gulp.watch(watchTarget, function(){
                        console.log(`files in ${watchTarget} seems to be modified, start reconvert @${ctimestr()}`)
                        converJs(env, obj.source, obj.dest);

                    });
                    break;
                case "browserify":
                    converBrowserifyJs(env, obj.source, obj.dest);
                    gulp.watch(watchTarget, function(){
                        console.log(`files in ${watchTarget} seems to be modified, start reconvert @${ctimestr()}`)
                        converBrowserifyJs(env, obj.source, obj.dest);
                    });
                    break;
                case "image":
                    compressImages(env, obj.source, obj.dest, obj.quality);
                    gulp.watch(watchTarget, function(){
                        console.log(watchTarget);
                        console.log(`files in ${watchTarget} seems to be modified, start compress @${ctimestr()}`)
                        compressImages(env, watchTarget, obj.dest, obj.quality);
                    });
                    break;

            }
        }

    });
}
function converCss(evn, source, dest){
    var lessobj = less();
    const cssnano = require('gulp-cssnano');
    const extname = path.extname(dest);
    const basename = path.basename(dest);
    var stream = gulp.src(source)
        .pipe(lessobj).on('error', function(error){
            console.log(error.toLocaleString());
            console.log('不能转换目标js');
            this.emit("end");
        });

    if(extname.length > 0){
        stream = stream.pipe(concat(basename));
        destPath = path.dirname(dest);
    }
    else {
        destPath = dest
    }
    stream = stream.pipe(cssnano())
        .pipe(rename(function(path){
            path.basename += '.min';
        }))
        .pipe(gulp.dest(destPath))
        .on('finish', function(file){
            console.log('finish convert css file');
        });
    return stream;
}
function converJs(evn, source, dest){
    const cssnano = require('gulp-cssnano');
    const extname = path.extname(dest);
    const basename = path.basename(dest);
    const sourceExtName = path.extname(source);

    var stream = gulp.src(source)
        .pipe(babel({
            presets: ['es2015']

        }).on('error', function(error){
            console.log(error.toLocaleString());
            console.log('不能转换目标js');
            this.emit("end")
        }))
        .pipe(uglify());

    var destPath;
    if(extname.length > 0){
        console.log('concat');
        stream = stream.pipe(concat(basename));
        destPath = path.dirname(dest);
    }else{
        destPath = dest
    }
    console.log(destPath);
    stream = stream.pipe(gulp.dest(destPath))
        .on('finish', function(file){
            console.log('finish convert js file');
        });
    return stream;
}
function converBrowserifyJs(env, source, dest){
    const extname = path.extname(dest);
    const destfolder = path.dirname(dest);
    if (extname.length == 0) return;
    console.log('browserify');
    var b = browserify({
        entries: source
    });
    return b.bundle()
        .on('error', function(err){
            console.log('browserify fail, can not convert\n' + source + "to \n" + dest);
            console.log(err);
        })
        .pipe(vsstream(path.basename(dest)))
        .pipe(gulp.dest(destfolder)).on('finish', function(file){
            console.log('finish build bundle js file');
        });
}
function compressImages(evn, source, dest, quality){
    gulp.src(source)
        .pipe(cache(imagemin({
            optimizationLevel: 0, //类型：Number  默认：3  取值范围：0-7（优化等级）
            //progressive: true, //类型：Boolean 默认：false 无损压缩jpg图片
            //interlaced: true, //类型：Boolean 默认：false 隔行扫描gif进行渲染
            //multipass: true, //类型：Boolean 默认：false 多次优化svg直到完全优化
            use:[
                imageRecompress({
                    accurate: false,//高精度模式
                    quality: "low",//图像质量:low, medium, high and veryhigh;
                    method: "smallfry",//网格优化:mpe, ssim, ms-ssim and smallfry;
                    min: 60,//最低质量
                    strip:true,
                    target:0.1,
                    loops: 6,//循环尝试次数, 默认为6;
                    progressive: true,//基线优化
                    subsample: "default"//子采样:default, disable;
                    }
                ),
                pngquant({
                    optimizationLevel: 4
                })
            ]
        })))
        .pipe(gulp.dest(dest))
        .on('finish', function(file){
            console.log('finish compress image');
        });;

}
function help(){
    console.log("webtool [<param>] -h");
    console.log("-h ——呼叫帮助");
    _.forEach(commands, function (obj){
        console.log(`<param>:${obj.command} -- ${obj.label}`);
    });
}
